@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.get_suspended_job_flow_response_200 import GetSuspendedJobFlowResponse200
 from ...types import UNSET, Response, Unset
 
@@ -13,15 +15,9 @@ def _get_kwargs(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
     approver: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs_u/get_flow/{id}/{resume_id}/{signature}".format(
-        client.base_url, workspace=workspace, id=id, resume_id=resume_id, signature=signature
-    )
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["approver"] = approver
@@ -30,28 +26,37 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs_u/get_flow/{id}/{resume_id}/{signature}".format(
+            workspace=workspace,
+            id=id,
+            resume_id=resume_id,
+            signature=signature,
+        ),
         "params": params,
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[GetSuspendedJobFlowResponse200]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[GetSuspendedJobFlowResponse200]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = GetSuspendedJobFlowResponse200.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[GetSuspendedJobFlowResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[GetSuspendedJobFlowResponse200]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -61,7 +66,7 @@ def sync_detailed(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[GetSuspendedJobFlowResponse200]:
     """get parent flow job of suspended job
@@ -73,6 +78,10 @@ def sync_detailed(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[GetSuspendedJobFlowResponse200]
     """
@@ -82,16 +91,14 @@ def sync_detailed(
         id=id,
         resume_id=resume_id,
         signature=signature,
-        client=client,
         approver=approver,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
@@ -100,7 +107,7 @@ def sync(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Optional[GetSuspendedJobFlowResponse200]:
     """get parent flow job of suspended job
@@ -112,8 +119,12 @@ def sync(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[GetSuspendedJobFlowResponse200]
+        GetSuspendedJobFlowResponse200
     """
 
     return sync_detailed(
@@ -132,7 +143,7 @@ async def asyncio_detailed(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[GetSuspendedJobFlowResponse200]:
     """get parent flow job of suspended job
@@ -144,6 +155,10 @@ async def asyncio_detailed(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[GetSuspendedJobFlowResponse200]
     """
@@ -153,14 +168,12 @@ async def asyncio_detailed(
         id=id,
         resume_id=resume_id,
         signature=signature,
-        client=client,
         approver=approver,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
@@ -169,7 +182,7 @@ async def asyncio(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Optional[GetSuspendedJobFlowResponse200]:
     """get parent flow job of suspended job
@@ -181,8 +194,12 @@ async def asyncio(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[GetSuspendedJobFlowResponse200]
+        GetSuspendedJobFlowResponse200
     """
 
     return (
