@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from ..models.completed_job_args import CompletedJobArgs
     from ..models.completed_job_flow_status import CompletedJobFlowStatus
     from ..models.completed_job_raw_flow import CompletedJobRawFlow
+    from ..models.completed_job_workflow_as_code_status import CompletedJobWorkflowAsCodeStatus
 
 
 T = TypeVar("T", bound="CompletedJob")
@@ -50,6 +51,7 @@ class CompletedJob:
         canceled_reason (Union[Unset, str]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, CompletedJobFlowStatus]):
+        workflow_as_code_status (Union[Unset, CompletedJobWorkflowAsCodeStatus]):
         raw_flow (Union[Unset, CompletedJobRawFlow]):
         language (Union[Unset, CompletedJobLanguage]):
         mem_peak (Union[Unset, int]):
@@ -88,6 +90,7 @@ class CompletedJob:
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "CompletedJobFlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "CompletedJobWorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "CompletedJobRawFlow"] = UNSET
     language: Union[Unset, CompletedJobLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -136,6 +139,10 @@ class CompletedJob:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -201,6 +208,8 @@ class CompletedJob:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -227,6 +236,7 @@ class CompletedJob:
         from ..models.completed_job_args import CompletedJobArgs
         from ..models.completed_job_flow_status import CompletedJobFlowStatus
         from ..models.completed_job_raw_flow import CompletedJobRawFlow
+        from ..models.completed_job_workflow_as_code_status import CompletedJobWorkflowAsCodeStatus
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -293,6 +303,13 @@ class CompletedJob:
         else:
             flow_status = CompletedJobFlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, CompletedJobWorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = CompletedJobWorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, CompletedJobRawFlow]
         if isinstance(_raw_flow, Unset):
@@ -349,6 +366,7 @@ class CompletedJob:
             canceled_reason=canceled_reason,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
