@@ -19,6 +19,8 @@ class CreateAccountJsonBody:
         cc_client_id (Union[Unset, str]): OAuth client ID for resource-level credentials (client_credentials flow only)
         cc_client_secret (Union[Unset, str]): OAuth client secret for resource-level credentials (client_credentials
             flow only)
+        cc_token_url (Union[Unset, str]): OAuth token URL override for resource-level authentication (client_credentials
+            flow only)
     """
 
     expires_in: int
@@ -27,6 +29,7 @@ class CreateAccountJsonBody:
     grant_type: Union[Unset, str] = "authorization_code"
     cc_client_id: Union[Unset, str] = UNSET
     cc_client_secret: Union[Unset, str] = UNSET
+    cc_token_url: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -36,6 +39,7 @@ class CreateAccountJsonBody:
         grant_type = self.grant_type
         cc_client_id = self.cc_client_id
         cc_client_secret = self.cc_client_secret
+        cc_token_url = self.cc_token_url
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -53,6 +57,8 @@ class CreateAccountJsonBody:
             field_dict["cc_client_id"] = cc_client_id
         if cc_client_secret is not UNSET:
             field_dict["cc_client_secret"] = cc_client_secret
+        if cc_token_url is not UNSET:
+            field_dict["cc_token_url"] = cc_token_url
 
         return field_dict
 
@@ -71,6 +77,8 @@ class CreateAccountJsonBody:
 
         cc_client_secret = d.pop("cc_client_secret", UNSET)
 
+        cc_token_url = d.pop("cc_token_url", UNSET)
+
         create_account_json_body = cls(
             expires_in=expires_in,
             client=client,
@@ -78,6 +86,7 @@ class CreateAccountJsonBody:
             grant_type=grant_type,
             cc_client_id=cc_client_id,
             cc_client_secret=cc_client_secret,
+            cc_token_url=cc_token_url,
         )
 
         create_account_json_body.additional_properties = d
