@@ -34,11 +34,15 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
         id (Union[Unset, str]):
         job (Union[Unset, str]):
         count (Union[Unset, int]):
+        progress (Union[Unset, int]):
         iterator (Union[Unset, DeleteCompletedJobResponse200FlowStatusFailureModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
+        flow_jobs_success (Union[Unset, List[bool]]):
         branch_chosen (Union[Unset, DeleteCompletedJobResponse200FlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, DeleteCompletedJobResponse200FlowStatusFailureModuleBranchall]):
         approvers (Union[Unset, List['DeleteCompletedJobResponse200FlowStatusFailureModuleApproversItem']]):
+        failed_retries (Union[Unset, List[str]]):
+        skipped (Union[Unset, bool]):
         parent_module (Union[Unset, str]):
     """
 
@@ -46,11 +50,15 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
+    progress: Union[Unset, int] = UNSET
     iterator: Union[Unset, "DeleteCompletedJobResponse200FlowStatusFailureModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
+    flow_jobs_success: Union[Unset, List[bool]] = UNSET
     branch_chosen: Union[Unset, "DeleteCompletedJobResponse200FlowStatusFailureModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "DeleteCompletedJobResponse200FlowStatusFailureModuleBranchall"] = UNSET
     approvers: Union[Unset, List["DeleteCompletedJobResponse200FlowStatusFailureModuleApproversItem"]] = UNSET
+    failed_retries: Union[Unset, List[str]] = UNSET
+    skipped: Union[Unset, bool] = UNSET
     parent_module: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -60,6 +68,7 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
         id = self.id
         job = self.job
         count = self.count
+        progress = self.progress
         iterator: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.iterator, Unset):
             iterator = self.iterator.to_dict()
@@ -68,6 +77,10 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
         if not isinstance(self.flow_jobs, Unset):
             flow_jobs = self.flow_jobs
 
+        flow_jobs_success: Union[Unset, List[bool]] = UNSET
+        if not isinstance(self.flow_jobs_success, Unset):
+            flow_jobs_success = self.flow_jobs_success
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -84,6 +97,11 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
 
                 approvers.append(approvers_item)
 
+        failed_retries: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.failed_retries, Unset):
+            failed_retries = self.failed_retries
+
+        skipped = self.skipped
         parent_module = self.parent_module
 
         field_dict: Dict[str, Any] = {}
@@ -99,16 +117,24 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
             field_dict["job"] = job
         if count is not UNSET:
             field_dict["count"] = count
+        if progress is not UNSET:
+            field_dict["progress"] = progress
         if iterator is not UNSET:
             field_dict["iterator"] = iterator
         if flow_jobs is not UNSET:
             field_dict["flow_jobs"] = flow_jobs
+        if flow_jobs_success is not UNSET:
+            field_dict["flow_jobs_success"] = flow_jobs_success
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
             field_dict["branchall"] = branchall
         if approvers is not UNSET:
             field_dict["approvers"] = approvers
+        if failed_retries is not UNSET:
+            field_dict["failed_retries"] = failed_retries
+        if skipped is not UNSET:
+            field_dict["skipped"] = skipped
         if parent_module is not UNSET:
             field_dict["parent_module"] = parent_module
 
@@ -138,6 +164,8 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
 
         count = d.pop("count", UNSET)
 
+        progress = d.pop("progress", UNSET)
+
         _iterator = d.pop("iterator", UNSET)
         iterator: Union[Unset, DeleteCompletedJobResponse200FlowStatusFailureModuleIterator]
         if isinstance(_iterator, Unset):
@@ -147,6 +175,8 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
 
         flow_jobs = cast(List[str], d.pop("flow_jobs", UNSET))
 
+        flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, DeleteCompletedJobResponse200FlowStatusFailureModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -170,6 +200,10 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
 
             approvers.append(approvers_item)
 
+        failed_retries = cast(List[str], d.pop("failed_retries", UNSET))
+
+        skipped = d.pop("skipped", UNSET)
+
         parent_module = d.pop("parent_module", UNSET)
 
         delete_completed_job_response_200_flow_status_failure_module = cls(
@@ -177,11 +211,15 @@ class DeleteCompletedJobResponse200FlowStatusFailureModule:
             id=id,
             job=job,
             count=count,
+            progress=progress,
             iterator=iterator,
             flow_jobs=flow_jobs,
+            flow_jobs_success=flow_jobs_success,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
+            failed_retries=failed_retries,
+            skipped=skipped,
             parent_module=parent_module,
         )
 
