@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.flow_preview_value_modules_item_mock import FlowPreviewValueModulesItemMock
     from ..models.flow_preview_value_modules_item_retry import FlowPreviewValueModulesItemRetry
+    from ..models.flow_preview_value_modules_item_skip_if import FlowPreviewValueModulesItemSkipIf
     from ..models.flow_preview_value_modules_item_sleep_type_0 import FlowPreviewValueModulesItemSleepType0
     from ..models.flow_preview_value_modules_item_sleep_type_1 import FlowPreviewValueModulesItemSleepType1
+    from ..models.flow_preview_value_modules_item_stop_after_all_iters_if import (
+        FlowPreviewValueModulesItemStopAfterAllItersIf,
+    )
     from ..models.flow_preview_value_modules_item_stop_after_if import FlowPreviewValueModulesItemStopAfterIf
     from ..models.flow_preview_value_modules_item_suspend import FlowPreviewValueModulesItemSuspend
 
@@ -24,6 +28,8 @@ class FlowPreviewValueModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, FlowPreviewValueModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, FlowPreviewValueModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, FlowPreviewValueModulesItemSkipIf]):
         sleep (Union['FlowPreviewValueModulesItemSleepType0', 'FlowPreviewValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class FlowPreviewValueModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "FlowPreviewValueModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "FlowPreviewValueModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "FlowPreviewValueModulesItemSkipIf"] = UNSET
     sleep: Union["FlowPreviewValueModulesItemSleepType0", "FlowPreviewValueModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class FlowPreviewValueModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class FlowPreviewValueModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class FlowPreviewValueModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.flow_preview_value_modules_item_mock import FlowPreviewValueModulesItemMock
         from ..models.flow_preview_value_modules_item_retry import FlowPreviewValueModulesItemRetry
+        from ..models.flow_preview_value_modules_item_skip_if import FlowPreviewValueModulesItemSkipIf
         from ..models.flow_preview_value_modules_item_sleep_type_0 import FlowPreviewValueModulesItemSleepType0
         from ..models.flow_preview_value_modules_item_sleep_type_1 import FlowPreviewValueModulesItemSleepType1
+        from ..models.flow_preview_value_modules_item_stop_after_all_iters_if import (
+            FlowPreviewValueModulesItemStopAfterAllItersIf,
+        )
         from ..models.flow_preview_value_modules_item_stop_after_if import FlowPreviewValueModulesItemStopAfterIf
         from ..models.flow_preview_value_modules_item_suspend import FlowPreviewValueModulesItemSuspend
 
@@ -146,6 +170,20 @@ class FlowPreviewValueModulesItem:
         else:
             stop_after_if = FlowPreviewValueModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, FlowPreviewValueModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = FlowPreviewValueModulesItemStopAfterAllItersIf.from_dict(_stop_after_all_iters_if)
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, FlowPreviewValueModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = FlowPreviewValueModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["FlowPreviewValueModulesItemSleepType0", "FlowPreviewValueModulesItemSleepType1", Unset]:
@@ -214,6 +252,8 @@ class FlowPreviewValueModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
