@@ -7,6 +7,9 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.get_job_updates_response_200_flow_status import GetJobUpdatesResponse200FlowStatus
+    from ..models.get_job_updates_response_200_workflow_as_code_status import (
+        GetJobUpdatesResponse200WorkflowAsCodeStatus,
+    )
 
 
 T = TypeVar("T", bound="GetJobUpdatesResponse200")
@@ -23,6 +26,7 @@ class GetJobUpdatesResponse200:
         mem_peak (Union[Unset, int]):
         progress (Union[Unset, int]):
         flow_status (Union[Unset, GetJobUpdatesResponse200FlowStatus]):
+        workflow_as_code_status (Union[Unset, GetJobUpdatesResponse200WorkflowAsCodeStatus]):
     """
 
     running: Union[Unset, bool] = UNSET
@@ -32,6 +36,7 @@ class GetJobUpdatesResponse200:
     mem_peak: Union[Unset, int] = UNSET
     progress: Union[Unset, int] = UNSET
     flow_status: Union[Unset, "GetJobUpdatesResponse200FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "GetJobUpdatesResponse200WorkflowAsCodeStatus"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -45,6 +50,10 @@ class GetJobUpdatesResponse200:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -62,12 +71,17 @@ class GetJobUpdatesResponse200:
             field_dict["progress"] = progress
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.get_job_updates_response_200_flow_status import GetJobUpdatesResponse200FlowStatus
+        from ..models.get_job_updates_response_200_workflow_as_code_status import (
+            GetJobUpdatesResponse200WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         running = d.pop("running", UNSET)
@@ -89,6 +103,13 @@ class GetJobUpdatesResponse200:
         else:
             flow_status = GetJobUpdatesResponse200FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, GetJobUpdatesResponse200WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = GetJobUpdatesResponse200WorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         get_job_updates_response_200 = cls(
             running=running,
             completed=completed,
@@ -97,6 +118,7 @@ class GetJobUpdatesResponse200:
             mem_peak=mem_peak,
             progress=progress,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
         )
 
         get_job_updates_response_200.additional_properties = d
