@@ -14,6 +14,9 @@ if TYPE_CHECKING:
     from ..models.list_jobs_response_200_item_type_0_args import ListJobsResponse200ItemType0Args
     from ..models.list_jobs_response_200_item_type_0_flow_status import ListJobsResponse200ItemType0FlowStatus
     from ..models.list_jobs_response_200_item_type_0_raw_flow import ListJobsResponse200ItemType0RawFlow
+    from ..models.list_jobs_response_200_item_type_0_workflow_as_code_status import (
+        ListJobsResponse200ItemType0WorkflowAsCodeStatus,
+    )
 
 
 T = TypeVar("T", bound="ListJobsResponse200ItemType0")
@@ -51,6 +54,7 @@ class ListJobsResponse200ItemType0:
         canceled_reason (Union[Unset, str]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, ListJobsResponse200ItemType0FlowStatus]):
+        workflow_as_code_status (Union[Unset, ListJobsResponse200ItemType0WorkflowAsCodeStatus]):
         raw_flow (Union[Unset, ListJobsResponse200ItemType0RawFlow]):
         language (Union[Unset, ListJobsResponse200ItemType0Language]):
         mem_peak (Union[Unset, int]):
@@ -90,6 +94,7 @@ class ListJobsResponse200ItemType0:
     canceled_reason: Union[Unset, str] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "ListJobsResponse200ItemType0FlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "ListJobsResponse200ItemType0WorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "ListJobsResponse200ItemType0RawFlow"] = UNSET
     language: Union[Unset, ListJobsResponse200ItemType0Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -139,6 +144,10 @@ class ListJobsResponse200ItemType0:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -207,6 +216,8 @@ class ListJobsResponse200ItemType0:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -235,6 +246,9 @@ class ListJobsResponse200ItemType0:
         from ..models.list_jobs_response_200_item_type_0_args import ListJobsResponse200ItemType0Args
         from ..models.list_jobs_response_200_item_type_0_flow_status import ListJobsResponse200ItemType0FlowStatus
         from ..models.list_jobs_response_200_item_type_0_raw_flow import ListJobsResponse200ItemType0RawFlow
+        from ..models.list_jobs_response_200_item_type_0_workflow_as_code_status import (
+            ListJobsResponse200ItemType0WorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -301,6 +315,15 @@ class ListJobsResponse200ItemType0:
         else:
             flow_status = ListJobsResponse200ItemType0FlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, ListJobsResponse200ItemType0WorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = ListJobsResponse200ItemType0WorkflowAsCodeStatus.from_dict(
+                _workflow_as_code_status
+            )
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, ListJobsResponse200ItemType0RawFlow]
         if isinstance(_raw_flow, Unset):
@@ -364,6 +387,7 @@ class ListJobsResponse200ItemType0:
             canceled_reason=canceled_reason,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
