@@ -13,6 +13,9 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_args import ListQueueResponse200ItemArgs
     from ..models.list_queue_response_200_item_flow_status import ListQueueResponse200ItemFlowStatus
     from ..models.list_queue_response_200_item_raw_flow import ListQueueResponse200ItemRawFlow
+    from ..models.list_queue_response_200_item_workflow_as_code_status import (
+        ListQueueResponse200ItemWorkflowAsCodeStatus,
+    )
 
 
 T = TypeVar("T", bound="ListQueueResponse200Item")
@@ -48,6 +51,7 @@ class ListQueueResponse200Item:
         last_ping (Union[Unset, datetime.datetime]):
         schedule_path (Union[Unset, str]):
         flow_status (Union[Unset, ListQueueResponse200ItemFlowStatus]):
+        workflow_as_code_status (Union[Unset, ListQueueResponse200ItemWorkflowAsCodeStatus]):
         raw_flow (Union[Unset, ListQueueResponse200ItemRawFlow]):
         language (Union[Unset, ListQueueResponse200ItemLanguage]):
         mem_peak (Union[Unset, int]):
@@ -84,6 +88,7 @@ class ListQueueResponse200Item:
     last_ping: Union[Unset, datetime.datetime] = UNSET
     schedule_path: Union[Unset, str] = UNSET
     flow_status: Union[Unset, "ListQueueResponse200ItemFlowStatus"] = UNSET
+    workflow_as_code_status: Union[Unset, "ListQueueResponse200ItemWorkflowAsCodeStatus"] = UNSET
     raw_flow: Union[Unset, "ListQueueResponse200ItemRawFlow"] = UNSET
     language: Union[Unset, ListQueueResponse200ItemLanguage] = UNSET
     mem_peak: Union[Unset, int] = UNSET
@@ -140,6 +145,10 @@ class ListQueueResponse200Item:
         if not isinstance(self.flow_status, Unset):
             flow_status = self.flow_status.to_dict()
 
+        workflow_as_code_status: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.workflow_as_code_status, Unset):
+            workflow_as_code_status = self.workflow_as_code_status.to_dict()
+
         raw_flow: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.raw_flow, Unset):
             raw_flow = self.raw_flow.to_dict()
@@ -203,6 +212,8 @@ class ListQueueResponse200Item:
             field_dict["schedule_path"] = schedule_path
         if flow_status is not UNSET:
             field_dict["flow_status"] = flow_status
+        if workflow_as_code_status is not UNSET:
+            field_dict["workflow_as_code_status"] = workflow_as_code_status
         if raw_flow is not UNSET:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
@@ -229,6 +240,9 @@ class ListQueueResponse200Item:
         from ..models.list_queue_response_200_item_args import ListQueueResponse200ItemArgs
         from ..models.list_queue_response_200_item_flow_status import ListQueueResponse200ItemFlowStatus
         from ..models.list_queue_response_200_item_raw_flow import ListQueueResponse200ItemRawFlow
+        from ..models.list_queue_response_200_item_workflow_as_code_status import (
+            ListQueueResponse200ItemWorkflowAsCodeStatus,
+        )
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -311,6 +325,13 @@ class ListQueueResponse200Item:
         else:
             flow_status = ListQueueResponse200ItemFlowStatus.from_dict(_flow_status)
 
+        _workflow_as_code_status = d.pop("workflow_as_code_status", UNSET)
+        workflow_as_code_status: Union[Unset, ListQueueResponse200ItemWorkflowAsCodeStatus]
+        if isinstance(_workflow_as_code_status, Unset):
+            workflow_as_code_status = UNSET
+        else:
+            workflow_as_code_status = ListQueueResponse200ItemWorkflowAsCodeStatus.from_dict(_workflow_as_code_status)
+
         _raw_flow = d.pop("raw_flow", UNSET)
         raw_flow: Union[Unset, ListQueueResponse200ItemRawFlow]
         if isinstance(_raw_flow, Unset):
@@ -365,6 +386,7 @@ class ListQueueResponse200Item:
             last_ping=last_ping,
             schedule_path=schedule_path,
             flow_status=flow_status,
+            workflow_as_code_status=workflow_as_code_status,
             raw_flow=raw_flow,
             language=language,
             mem_peak=mem_peak,
