@@ -16,6 +16,9 @@ if TYPE_CHECKING:
     from ..models.list_schedules_response_200_item_on_recovery_extra_args import (
         ListSchedulesResponse200ItemOnRecoveryExtraArgs,
     )
+    from ..models.list_schedules_response_200_item_on_success_extra_args import (
+        ListSchedulesResponse200ItemOnSuccessExtraArgs,
+    )
     from ..models.list_schedules_response_200_item_retry import ListSchedulesResponse200ItemRetry
 
 
@@ -45,11 +48,16 @@ class ListSchedulesResponse200Item:
         on_recovery (Union[Unset, str]):
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, ListSchedulesResponse200ItemOnRecoveryExtraArgs]):
+        on_success (Union[Unset, str]):
+        on_success_extra_args (Union[Unset, ListSchedulesResponse200ItemOnSuccessExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
         retry (Union[Unset, ListSchedulesResponse200ItemRetry]):
         summary (Union[Unset, str]):
+        description (Union[Unset, str]):
         no_flow_overlap (Union[Unset, bool]):
         tag (Union[Unset, str]):
+        paused_until (Union[Unset, datetime.datetime]):
+        cron_version (Union[Unset, str]):
     """
 
     path: str
@@ -71,11 +79,16 @@ class ListSchedulesResponse200Item:
     on_recovery: Union[Unset, str] = UNSET
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "ListSchedulesResponse200ItemOnRecoveryExtraArgs"] = UNSET
+    on_success: Union[Unset, str] = UNSET
+    on_success_extra_args: Union[Unset, "ListSchedulesResponse200ItemOnSuccessExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
     retry: Union[Unset, "ListSchedulesResponse200ItemRetry"] = UNSET
     summary: Union[Unset, str] = UNSET
+    description: Union[Unset, str] = UNSET
     no_flow_overlap: Union[Unset, bool] = UNSET
     tag: Union[Unset, str] = UNSET
+    paused_until: Union[Unset, datetime.datetime] = UNSET
+    cron_version: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -109,14 +122,25 @@ class ListSchedulesResponse200Item:
         if not isinstance(self.on_recovery_extra_args, Unset):
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
+        on_success = self.on_success
+        on_success_extra_args: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.on_success_extra_args, Unset):
+            on_success_extra_args = self.on_success_extra_args.to_dict()
+
         ws_error_handler_muted = self.ws_error_handler_muted
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
 
         summary = self.summary
+        description = self.description
         no_flow_overlap = self.no_flow_overlap
         tag = self.tag
+        paused_until: Union[Unset, str] = UNSET
+        if not isinstance(self.paused_until, Unset):
+            paused_until = self.paused_until.isoformat()
+
+        cron_version = self.cron_version
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -152,16 +176,26 @@ class ListSchedulesResponse200Item:
             field_dict["on_recovery_times"] = on_recovery_times
         if on_recovery_extra_args is not UNSET:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
+        if on_success is not UNSET:
+            field_dict["on_success"] = on_success
+        if on_success_extra_args is not UNSET:
+            field_dict["on_success_extra_args"] = on_success_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
         if retry is not UNSET:
             field_dict["retry"] = retry
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if description is not UNSET:
+            field_dict["description"] = description
         if no_flow_overlap is not UNSET:
             field_dict["no_flow_overlap"] = no_flow_overlap
         if tag is not UNSET:
             field_dict["tag"] = tag
+        if paused_until is not UNSET:
+            field_dict["paused_until"] = paused_until
+        if cron_version is not UNSET:
+            field_dict["cron_version"] = cron_version
 
         return field_dict
 
@@ -175,6 +209,9 @@ class ListSchedulesResponse200Item:
         from ..models.list_schedules_response_200_item_on_recovery_extra_args import (
             ListSchedulesResponse200ItemOnRecoveryExtraArgs,
         )
+        from ..models.list_schedules_response_200_item_on_success_extra_args import (
+            ListSchedulesResponse200ItemOnSuccessExtraArgs,
+        )
         from ..models.list_schedules_response_200_item_retry import ListSchedulesResponse200ItemRetry
 
         d = src_dict.copy()
@@ -231,6 +268,15 @@ class ListSchedulesResponse200Item:
         else:
             on_recovery_extra_args = ListSchedulesResponse200ItemOnRecoveryExtraArgs.from_dict(_on_recovery_extra_args)
 
+        on_success = d.pop("on_success", UNSET)
+
+        _on_success_extra_args = d.pop("on_success_extra_args", UNSET)
+        on_success_extra_args: Union[Unset, ListSchedulesResponse200ItemOnSuccessExtraArgs]
+        if isinstance(_on_success_extra_args, Unset):
+            on_success_extra_args = UNSET
+        else:
+            on_success_extra_args = ListSchedulesResponse200ItemOnSuccessExtraArgs.from_dict(_on_success_extra_args)
+
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
         _retry = d.pop("retry", UNSET)
@@ -242,10 +288,21 @@ class ListSchedulesResponse200Item:
 
         summary = d.pop("summary", UNSET)
 
+        description = d.pop("description", UNSET)
+
         no_flow_overlap = d.pop("no_flow_overlap", UNSET)
 
         tag = d.pop("tag", UNSET)
 
+        _paused_until = d.pop("paused_until", UNSET)
+        paused_until: Union[Unset, datetime.datetime]
+        if isinstance(_paused_until, Unset):
+            paused_until = UNSET
+        else:
+            paused_until = isoparse(_paused_until)
+
+        cron_version = d.pop("cron_version", UNSET)
+
         list_schedules_response_200_item = cls(
             path=path,
             edited_by=edited_by,
@@ -266,11 +323,16 @@ class ListSchedulesResponse200Item:
             on_recovery=on_recovery,
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
+            on_success=on_success,
+            on_success_extra_args=on_success_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
             retry=retry,
             summary=summary,
+            description=description,
             no_flow_overlap=no_flow_overlap,
             tag=tag,
+            paused_until=paused_until,
+            cron_version=cron_version,
         )
 
         list_schedules_response_200_item.additional_properties = d
