@@ -21,6 +21,7 @@ class Preview:
         args (PreviewArgs):
         content (Union[Unset, str]):
         path (Union[Unset, str]):
+        script_hash (Union[Unset, str]):
         language (Union[Unset, PreviewLanguage]):
         tag (Union[Unset, str]):
         kind (Union[Unset, PreviewKind]):
@@ -31,6 +32,7 @@ class Preview:
     args: "PreviewArgs"
     content: Union[Unset, str] = UNSET
     path: Union[Unset, str] = UNSET
+    script_hash: Union[Unset, str] = UNSET
     language: Union[Unset, PreviewLanguage] = UNSET
     tag: Union[Unset, str] = UNSET
     kind: Union[Unset, PreviewKind] = UNSET
@@ -43,6 +45,7 @@ class Preview:
 
         content = self.content
         path = self.path
+        script_hash = self.script_hash
         language: Union[Unset, str] = UNSET
         if not isinstance(self.language, Unset):
             language = self.language.value
@@ -66,6 +69,8 @@ class Preview:
             field_dict["content"] = content
         if path is not UNSET:
             field_dict["path"] = path
+        if script_hash is not UNSET:
+            field_dict["script_hash"] = script_hash
         if language is not UNSET:
             field_dict["language"] = language
         if tag is not UNSET:
@@ -90,6 +95,8 @@ class Preview:
 
         path = d.pop("path", UNSET)
 
+        script_hash = d.pop("script_hash", UNSET)
+
         _language = d.pop("language", UNSET)
         language: Union[Unset, PreviewLanguage]
         if isinstance(_language, Unset):
@@ -114,6 +121,7 @@ class Preview:
             args=args,
             content=content,
             path=path,
+            script_hash=script_hash,
             language=language,
             tag=tag,
             kind=kind,
